import React, { FC, memo } from 'react';
import { useDisclosure } from '@chakra-ui/react';
import { Form, Formik } from 'formik';

import { Forms } from 'src/components';

import validationSchema from './validationSchema';
import ModalComponent from 'src/components/ModalComponent';

interface FormValues {
    name: string;
    position: string;
    leg: string;
    date_of_birth: string;
    games: number;
}

interface IAddPlayerForm {
    buttonType: string;
    buttonText?: string;
    buttonColorScheme?: string;
    initialValues: FormValues;
    handleSubmit: Function;
}

const AddPlayerForm: FC<IAddPlayerForm> = ({
    buttonType,
    buttonText,
    buttonColorScheme,
    initialValues,
    handleSubmit,
}) => {
    const { isOpen, onOpen, onClose } = useDisclosure();
    return (
        <>
            <ModalComponent
                buttonType={buttonType}
                buttonText={buttonText}
                buttonColorScheme={buttonColorScheme}
                secondButton="submit"
                formID="modalAddPlayerForm"
                isOpen={isOpen}
                onOpen={onOpen}
                onClose={onClose}
            >
                <Formik
                    validationSchema={validationSchema}
                    initialValues={initialValues}
                    onSubmit={(values) => handleSubmit(values).then(() => onClose())}
                >
                    {({ errors, touched, initialValues, setFieldValue }) => (
                        <Form id="modalAddPlayerForm" autoComplete="off">
                            <Forms.FormField
                                errorMessage={errors.name || ''}
                                isInvalid={(errors.name && touched.name) || false}
                                label="Name:"
                                name="name"
                                placeholder="name"
                                initialValue={initialValues.name}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormField
                                errorMessage={errors.position || ''}
                                isInvalid={(errors.position && touched.position) || false}
                                label="Position:"
                                name="position"
                                placeholder="position"
                                initialValue={initialValues.position}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormField
                                errorMessage={errors.leg || ''}
                                isInvalid={(errors.leg && touched.leg) || false}
                                label="Leg:"
                                name="leg"
                                placeholder="leg"
                                initialValue={initialValues.leg}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormDate
                                errorMessage={errors.date_of_birth || ''}
                                isInvalid={(errors.date_of_birth && touched.date_of_birth) || false}
                                label="Date of birth:"
                                name="date_of_birth"
                                placeholder="date of birth"
                                initialValue={initialValues.date_of_birth}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormField
                                errorMessage={errors.games || ''}
                                isInvalid={(errors.games && touched.games) || false}
                                label="Games:"
                                name="games"
                                placeholder="games"
                                initialValue={initialValues.games}
                                setFieldValue={setFieldValue}
                            />
                        </Form>
                    )}
                </Formik>
            </ModalComponent>
        </>
    );
};

export default memo(AddPlayerForm);
