import React, { FC, memo, useCallback } from 'react';
import { Flex, Text, Heading, Icon } from '@chakra-ui/react';
import { useSelector } from 'react-redux';
import { useNavigate } from 'react-router-dom';

import { players, power, statistics } from 'src/components/icons';

import { paths } from 'src/constants';

import { actions, dispatch, selectors } from 'src/store';

import { Emblem } from 'src/components';

const Drawer: FC = () => {
    const action = dispatch();
    const navigate = useNavigate();
    const user = useSelector(selectors.auth.selectAuthUser);
    const { logout } = actions.auth;

    const logoutUser = useCallback(() => {
        return action(logout());
    }, [action, logout]);

    return (
        <Flex width="30%" height="100%" maxWidth="350px">
            <Flex
                position="fixed"
                direction="column"
                boxShadow="common"
                textAlign="center"
                justifyContent="space-around"
                overflowY="auto"
                overflowX="hidden"
                fontSize="2xl"
                bg="white"
                width="30%"
                height="100%"
                maxWidth="350px"
            >
                <Flex direction="column">
                    <Emblem />
                    <Text color="blue.100">Welcome</Text>
                    <Heading color="blue.100" textDecor="underline">
                        {user?.first_name || user?.username}
                    </Heading>
                </Flex>
                <Flex direction="column">
                    <Flex
                        onClick={() => navigate(paths.PLAYERS)}
                        justifyContent="center"
                        alignItems="center"
                        _hover={{ bg: 'blue.10', cursor: 'pointer' }}
                    >
                        <Icon marginRight="10px" as={players} />
                        <Text color="blue.100">Players</Text>
                    </Flex>
                    <Flex
                        onClick={() => navigate(paths.STATISTICS)}
                        justifyContent="center"
                        alignItems="center"
                        _hover={{ bg: 'blue.10', cursor: 'pointer' }}
                    >
                        <Icon marginRight="10px" as={statistics} />
                        <Text color="blue.100">Statistics</Text>
                    </Flex>
                </Flex>
                <Flex
                    onClick={logoutUser}
                    justifyContent="center"
                    alignItems="center"
                    _hover={{ bg: 'blue.10', cursor: 'pointer' }}
                >
                    <Icon marginRight="10px" as={power} />
                    <Text color="blue.100">Logout</Text>
                </Flex>
            </Flex>
        </Flex>
    );
};

export default memo(Drawer);
