import React, { FC, memo } from 'react';
import {
    Box,
    Checkbox,
    CheckboxGroup,
    FormControl,
    FormErrorMessage,
    FormLabel,
    Stack,
} from '@chakra-ui/react';

interface IFormChoice {
    errorMessage: string | string[];
    isInvalid: boolean;
    label: string;
    name: string;
    type?: string;
    onChange?: any;
    choices: string[];
    value: any;
}

const FormChoice: FC<IFormChoice> = ({
    errorMessage,
    isInvalid,
    label,
    name,
    onChange,
    choices,
}) => {
    return (
        <>
            <FormLabel textAlign="center" color="darkgoldenrod" fontWeight="bold" cursor="pointer">
                {label}
            </FormLabel>
            <FormControl isInvalid={isInvalid} onChange={onChange}>
                <CheckboxGroup>
                    <Stack align="left">
                        {choices.map((choice, index) => {
                            return (
                                <Checkbox
                                    color="blue.100"
                                    colorScheme="yellow"
                                    name={name}
                                    value={String(index + 1)}
                                    key={name + index}
                                >
                                    {choice}
                                </Checkbox>
                            );
                        })}
                    </Stack>
                </CheckboxGroup>
                <Box height="5">
                    <FormErrorMessage fontSize="xxs" marginTop="xxs" marginLeft="xs">
                        {errorMessage[0] || errorMessage}
                    </FormErrorMessage>
                </Box>
            </FormControl>
        </>
    );
};

export default memo(FormChoice);
