import React, { FC, memo } from 'react';
import {
    Box,
    FormControl,
    FormErrorMessage,
    FormLabel,
    Input,
    InputGroup,
    InputRightAddon,
    NumberDecrementStepper,
    NumberIncrementStepper,
    NumberInput,
    NumberInputField,
    NumberInputStepper,
} from '@chakra-ui/react';

interface IFormField {
    errorMessage: string;
    isInvalid: boolean;
    label: string;
    name: string;
    initialValue?: string | number;
    placeholder: string;
    setFieldValue: Function;
    type?: string;
    value?: string | number;
}

const FormField: FC<IFormField> = ({
    errorMessage,
    isInvalid,
    label,
    name,
    initialValue,
    placeholder,
    setFieldValue,
    type,
    value,
}) => {
    const formStyling = ['height', 'weight', 'BP', 'games', 'position', 'leg'].includes(name)
        ? {
              display: 'flex',
              flexDirection: 'column' as 'column',
              alignItems: 'center',
          }
        : {};

    const inputWidth = ['height', 'weight', 'BP', 'games', 'position', 'leg'].includes(name)
        ? '150px'
        : 'auto';

    return (
        <>
            <FormLabel
                htmlFor={name}
                textAlign="center"
                color="blue.100"
                fontWeight="bold"
                cursor="pointer"
            >
                {label}
            </FormLabel>
            <FormControl isInvalid={isInvalid} style={formStyling}>
                <InputGroup width={inputWidth}>
                    {['height', 'weight', 'games'].includes(name) ? (
                        <NumberInput
                            id={name}
                            name={name}
                            type={type}
                            values={value}
                            defaultValue={initialValue}
                            placeholder={placeholder}
                            onChange={(event) => {
                                setFieldValue(name, event);
                            }}
                            error={isInvalid || 'false'}
                        >
                            <NumberInputField textAlign="center" />
                            <NumberInputStepper>
                                <NumberIncrementStepper color="blue.100" />
                                <NumberDecrementStepper color="blue.100" />
                            </NumberInputStepper>
                        </NumberInput>
                    ) : (
                        <Input
                            id={name}
                            name={name}
                            type={type}
                            value={value}
                            defaultValue={initialValue}
                            placeholder={placeholder}
                            onChange={(event) => setFieldValue(name, event.target.value)}
                            error={`${isInvalid}`}
                            textAlign="center"
                        />
                    )}
                    {name === 'height' && (
                        <InputRightAddon color="darkgoldenrod">cm</InputRightAddon>
                    )}
                    {name === 'weight' && (
                        <InputRightAddon color="darkgoldenrod">kg</InputRightAddon>
                    )}
                </InputGroup>
                <Box height="5">
                    <FormErrorMessage fontSize="xxs" marginTop="xxs" marginLeft="xs">
                        {errorMessage}
                    </FormErrorMessage>
                </Box>
            </FormControl>
        </>
    );
};

export default memo(FormField);
