import React, { FC, memo, useEffect, useRef, useState } from 'react';
import {
    Box,
    Button,
    Flex,
    FormControl,
    FormErrorMessage,
    FormLabel,
    Input,
} from '@chakra-ui/react';
import { DeleteIcon } from '@chakra-ui/icons';

interface IFormFile {
    errorMessage: string;
    isInvalid: boolean;
    label: string;
    name: string;
    placeholder: string;
    setFieldValue: Function;
    type?: string;
    value?: any;
}

const FormFile: FC<IFormFile> = ({
    errorMessage,
    isInvalid,
    label,
    name,
    placeholder,
    setFieldValue,
    type,
    value,
}) => {
    const [fieldText, setFieldText] = useState('');
    const fileInput = useRef<HTMLInputElement>(null);

    useEffect(() => {
        if (!value) {
            setFieldText('');
        }
    }, [value]);

    return (
        <Flex direction="column" alignContent="center">
            <FormLabel
                htmlFor={name}
                textAlign="center"
                color="blue.100"
                fontWeight="bold"
                cursor="pointer"
            >
                {label}
            </FormLabel>
            {fieldText && (
                <Flex justifyContent="center">
                    {fieldText}
                    &emsp;
                    <Button
                        size="sm"
                        onClick={() => {
                            setFieldValue(name, '');
                            setFieldText('');
                        }}
                    >
                        <DeleteIcon textColor="darkgoldenrod" fontSize="medium" />
                    </Button>
                </Flex>
            )}
            <FormControl isInvalid={isInvalid} display="flex" justifyContent="center">
                <Input
                    id={name}
                    name={name}
                    type={type}
                    ref={fileInput}
                    multiple={false}
                    placeholder={placeholder}
                    onChange={(event) => {
                        if (event.target.files) {
                            setFieldValue(name, event.target.files[0]);
                            setFieldText(event.target.files[0].name);
                        }
                    }}
                    error={isInvalid || 'false'}
                    style={{ display: 'none' }}
                />
                <Button colorScheme="twitter" onClick={() => fileInput?.current?.click()}>
                    Choose File
                </Button>
                <Box height="5">
                    <FormErrorMessage fontSize="xxs" marginTop="xxs" marginLeft="xs">
                        {errorMessage}
                    </FormErrorMessage>
                </Box>
            </FormControl>
        </Flex>
    );
};

export default memo(FormFile);
