import React, { FC, memo, useCallback } from 'react';
import { useDisclosure } from '@chakra-ui/react';
import { Form, Formik } from 'formik';

import { actions, dispatch } from 'src/store';

import { Forms } from 'src/components';

import validationSchema from './validationSchema';
import ModalComponent from 'src/components/ModalComponent';

interface FormValues {
    player_id?: number;
    height?: number;
    weight?: number;
    BP?: string;
}

interface IGeneralForm {
    buttonType: string;
    initialValues: FormValues;
}

const GeneralForm: FC<IGeneralForm> = ({ buttonType, initialValues }) => {
    const { isOpen, onOpen, onClose } = useDisclosure();
    const action = dispatch();

    const { addGeneralOverview } = actions.general;

    const handleGeneralOverviewChange = useCallback(
        async (values) => {
            const response = await action(addGeneralOverview(values));
            if (response.type === 'addGeneralOverview/fulfilled') {
                onClose();
            }
        },
        [action, addGeneralOverview, onClose],
    );

    return (
        <>
            <ModalComponent
                buttonType={buttonType}
                secondButton="submit"
                formID="modalGeneralForm"
                isOpen={isOpen}
                onOpen={onOpen}
                onClose={onClose}
            >
                <Formik
                    validationSchema={validationSchema}
                    initialValues={initialValues}
                    onSubmit={(values) => handleGeneralOverviewChange(values)}
                >
                    {({ errors, touched, initialValues, setFieldValue }) => (
                        <Form id="modalGeneralForm" autoComplete="off">
                            <Forms.FormField
                                errorMessage={errors.height || ''}
                                isInvalid={(errors.height && touched.height) || false}
                                label="Height:"
                                name="height"
                                placeholder="height"
                                initialValue={initialValues.height}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormField
                                errorMessage={errors.weight || ''}
                                isInvalid={(errors.weight && touched.weight) || false}
                                label="Weight:"
                                name="weight"
                                placeholder="weight"
                                initialValue={initialValues.weight}
                                setFieldValue={setFieldValue}
                            />
                            <Forms.FormField
                                errorMessage={errors.BP || ''}
                                isInvalid={(errors.BP && touched.BP) || false}
                                label="Blood Pressure:"
                                name="BP"
                                placeholder="(eg. 120/80)"
                                setFieldValue={setFieldValue}
                            />
                        </Form>
                    )}
                </Formik>
            </ModalComponent>
        </>
    );
};

export default memo(GeneralForm);
