import React, { FC, memo, useEffect, ReactElement } from 'react';
import { useDispatch, useSelector } from 'react-redux';

import { actions, selectors } from 'src/store';

interface IInitProvider {
    children: ReactElement<any, any> | null;
}

const InitProvider: FC<IInitProvider> = ({ children }: IInitProvider) => {
    const dispatch = useDispatch();
    const isAuthenticated = !!localStorage.getItem('accessToken');
    const user = useSelector(selectors.auth.selectAuthUser);
    const arePlayersLoaded: boolean = useSelector(selectors.players.selectHasLoaded);

    useEffect(() => {
        if (isAuthenticated) {
            dispatch(actions.auth.health());
        }
    }, [dispatch, isAuthenticated]);

    useEffect(() => {
        if (isAuthenticated) {
            dispatch(actions.players.getPlayers());
        }
    }, [dispatch, isAuthenticated, user]);

    if ((isAuthenticated && arePlayersLoaded) || !isAuthenticated) {
        return <>{children}</>;
    }

    return null;
};

export default memo(InitProvider);
