import React, { FC, memo, useCallback, useState } from 'react';

import {
    Button,
    Flex,
    ListItem,
    OrderedList,
    Table,
    Tbody,
    Td,
    Tr,
    useDisclosure,
} from '@chakra-ui/react';
import { DeleteIcon } from '@chakra-ui/icons';

import { actions, dispatch } from 'src/store';

import { ModalComponent } from 'src/components';

import { GeneralData } from 'src/constants/interfaces/generalMedicalOverview';
import { AnamnesisData } from 'src/constants/interfaces/medicalAnamnesis';

interface IListItems {
    data?: Array<GeneralData | AnamnesisData>;
}

const ListItems: FC<IListItems> = ({ data }) => {
    const { isOpen, onOpen, onClose } = useDisclosure();
    const [visibleItem, setVisibleItem] = useState<GeneralData | AnamnesisData>();
    const action = dispatch();
    const { deleteGeneralOverview } = actions.general;
    const { deleteMedicalAnamnesis } = actions.medicalAnamnesis;

    const handleClick = useCallback(
        (item: GeneralData | AnamnesisData) => {
            visibleItem === item ? setVisibleItem(undefined) : setVisibleItem(item);
        },
        [visibleItem],
    );

    const handleGeneralOverviewDelete = useCallback(
        (data: GeneralData | AnamnesisData) => {
            'BP' in data
                ? action(deleteGeneralOverview(data)).then((response) => console.log(response))
                : action(deleteMedicalAnamnesis(data)).then((response) => console.log(response));
        },
        [action, deleteGeneralOverview, deleteMedicalAnamnesis],
    );

    const getDisplayItem = (item: GeneralData | AnamnesisData) => {
        // eslint-disable-next-line no-unused-vars
        const { id, time_made, player, ...displayItem } = item;

        return displayItem;
    };

    const getDisplayData = (data: Array<GeneralData | AnamnesisData>) => {
        const displayData = [...data].sort(
            (a, b) => new Date(b.time_made).getTime() - new Date(a.time_made).getTime(),
        );

        return displayData;
    };

    return (
        <ModalComponent
            buttonType="list"
            formID="modalGeneralForm"
            isOpen={isOpen}
            onOpen={onOpen}
            onClose={onClose}
        >
            {data?.[0] &&
                getDisplayData(data).map((item) => (
                    <Flex direction="column" key={item.id}>
                        <Flex justifyContent="space-evenly">
                            <Button
                                color="darkgoldenrod"
                                variant="ghost"
                                onClick={() => handleClick(item)}
                            >
                                {new Date(item.time_made).toDateString()}
                            </Button>
                            <Button size="sm" onClick={() => handleGeneralOverviewDelete(item)}>
                                <DeleteIcon textColor="darkgoldenrod" fontSize="medium" />
                            </Button>
                        </Flex>
                        {visibleItem === item && (
                            <Table variant="unstyled" color="blue.100">
                                <Tbody>
                                    {Object.keys(getDisplayItem(item)).map((key) =>
                                        typeof (item as any)[key] === typeof [] ? (
                                            <>
                                                <Tr key={item.id + key}>
                                                    <Td padding="5px" color="darkgoldenrod">
                                                        {key}
                                                    </Td>
                                                </Tr>
                                                <Tr key={`${item.id + key}2`}>
                                                    <Td padding="5px" paddingLeft="15px">
                                                        <OrderedList>
                                                            {(item as any)[key].map(
                                                                (instance: any) => (
                                                                    <ListItem key={instance.value}>
                                                                        {instance.text}
                                                                    </ListItem>
                                                                ),
                                                            )}
                                                        </OrderedList>
                                                    </Td>
                                                </Tr>
                                            </>
                                        ) : (
                                            <Tr key={item.id + key}>
                                                <Td padding="5px">{key}</Td>
                                                <Td padding="5px">{(item as any)[key]}</Td>
                                            </Tr>
                                        ),
                                    )}
                                </Tbody>
                            </Table>
                        )}
                    </Flex>
                ))}
        </ModalComponent>
    );
};

export default memo(ListItems);
