import React, { FC, memo } from 'react';
import { Button, Flex } from '@chakra-ui/react';
import { Formik, Form } from 'formik';

import { Forms } from 'src/components';

import validationSchema from './validationSchema';

interface FormValues {
    username: string;
    password: string;
}

interface ILoginForm {
    initialValues: FormValues;
    handleSubmit: Function;
}

const LoginForm: FC<ILoginForm> = ({ initialValues, handleSubmit }) => {
    return (
        <Formik
            validationSchema={validationSchema}
            initialValues={initialValues}
            onSubmit={(values) => handleSubmit(values)}
        >
            {({ errors, touched, setFieldValue }) => (
                <Form>
                    <Forms.FormField
                        errorMessage={errors.username || ''}
                        isInvalid={(errors.username && touched.username) || false}
                        label="Username:"
                        name="username"
                        placeholder="Enter username"
                        setFieldValue={setFieldValue}
                    />
                    <Forms.FormField
                        errorMessage={errors.password || ''}
                        isInvalid={(errors.password && touched.password) || false}
                        label="Password:"
                        name="password"
                        type="password"
                        placeholder="Enter password"
                        setFieldValue={setFieldValue}
                    />
                    <Flex placeContent="center">
                        <Button width="100px" type="submit" color="green">
                            Login
                        </Button>
                    </Flex>
                </Form>
            )}
        </Formik>
    );
};

export default memo(LoginForm);
