import React, { FC, memo } from 'react';

import {
    Button,
    Modal,
    ModalBody,
    ModalCloseButton,
    ModalContent,
    ModalFooter,
    ModalOverlay,
    ModalProps,
} from '@chakra-ui/react';
import { AddIcon, EditIcon, HamburgerIcon } from '@chakra-ui/icons';

interface IModalComponent extends ModalProps {
    buttonType: string;
    buttonText?: string;
    buttonColorScheme?: string;
    secondButton?: 'button' | 'submit' | 'reset';
    formID?: string;
    isOpen: boolean;
    onOpen: () => void;
    onClose: () => void;
}
/**
 * Modal hook that manages all the logic for the modal dialog widget
 * and returns prop getters, state and actions.
 *
 * @param props
 */

const ModalComponent: FC<IModalComponent> = (props) => {
    const {
        children,
        buttonType,
        buttonText,
        buttonColorScheme,
        secondButton,
        formID,
        onOpen,
        isOpen,
        onClose,
    } = props;

    return (
        <>
            <Button
                alignSelf="center"
                maxWidth="500px"
                colorScheme={buttonColorScheme}
                color="blue.10"
                backgroundColor="darkgoldenrod"
                _hover={{
                    backgroundColor: 'goldenrod',
                    '.chakra-icon': { transform: 'rotate(180deg) scale(1.2)' },
                }}
                fontSize="large"
                onClick={onOpen}
            >
                {buttonType === 'pencil' && (
                    <EditIcon style={{ transition: 'transform .4s ease-in-out' }} />
                )}
                {buttonType === 'plus' && (
                    <AddIcon style={{ transition: 'transform .4s ease-in-out' }} />
                )}
                {buttonType === 'list' && (
                    <HamburgerIcon style={{ transition: 'transform .4s ease-in-out' }} />
                )}
                {buttonText}
            </Button>

            <Modal isOpen={isOpen} onClose={onClose}>
                <ModalOverlay />
                <ModalContent>
                    <ModalCloseButton textColor="darkgoldenrod" />
                    <ModalBody mt="15px">{children}</ModalBody>
                    <ModalFooter
                        paddingY="10px"
                        borderTop="2px"
                        borderTopStyle="dotted"
                        borderTopColor="blue.100"
                    >
                        <Button variant="solid" colorScheme="red" mr="10px" onClick={onClose}>
                            Close
                        </Button>
                        {secondButton && (
                            <Button
                                variant="solid"
                                colorScheme="green"
                                onClick={() => {
                                    onClose;
                                }}
                                type={secondButton}
                                form={formID}
                            >
                                {secondButton
                                    ?.charAt(0)
                                    .toUpperCase()
                                    .concat(secondButton?.slice(1))}
                            </Button>
                        )}
                    </ModalFooter>
                </ModalContent>
            </Modal>
        </>
    );
};

export default memo(ModalComponent);
