import React, { FC, memo, useCallback } from 'react';

import { Button, Flex, Table, Tbody, Td, Tr, useDisclosure } from '@chakra-ui/react';
import { DeleteIcon } from '@chakra-ui/icons';

import { actions, dispatch } from 'src/store';

import { VaccinationData } from 'src/constants/interfaces/vaccination';

import { ModalComponent, VaccinationForm } from 'src/components';

interface IModalDeleteForm {
    vaccination?: Array<VaccinationData>;
    initialValues: {
        player_id?: number;
        disease: string;
        date: string;
    };
}
/**
 * Modal hook that manages all the logic for the modal dialog widget
 * and returns prop getters, state and actions.
 *
 * @param props
 */

const ModalDeleteForm: FC<IModalDeleteForm> = (props) => {
    const { vaccination, initialValues } = props;
    const { isOpen, onOpen, onClose } = useDisclosure();
    const action = dispatch();
    const { deleteVaccine } = actions.vaccination;

    const handleVaccineDelete = useCallback(
        (values) => {
            return action(deleteVaccine(values));
        },
        [action, deleteVaccine],
    );

    return (
        <ModalComponent
            buttonType="pencil"
            formID="modalVaccinationForm"
            isOpen={isOpen}
            onOpen={onOpen}
            onClose={onClose}
        >
            <Flex flexDirection="column" alignContent="center">
                {vaccination?.[0] && (
                    <Table variant="unstyled" textColor="blue.100">
                        <Tbody>
                            {vaccination.map((vaccine) => {
                                return (
                                    <Tr key={vaccine.id}>
                                        <Td paddingY="2px" paddingRight="2px">
                                            {vaccine.disease}
                                        </Td>
                                        <Td paddingY="5px" paddingLeft="0">
                                            <Button
                                                size="sm"
                                                onClick={() => handleVaccineDelete(vaccine)}
                                            >
                                                <DeleteIcon
                                                    textColor="darkgoldenrod"
                                                    fontSize="medium"
                                                />
                                            </Button>
                                        </Td>
                                    </Tr>
                                );
                            })}
                        </Tbody>
                    </Table>
                )}
                <VaccinationForm initialValues={initialValues} />
            </Flex>
        </ModalComponent>
    );
};

export default memo(ModalDeleteForm);
