import { Flex } from '@chakra-ui/react';
import _ from 'lodash';
import React, { FC, memo } from 'react';
import { Pie } from 'react-chartjs-2';

interface IPieChartComponent {
    chartData: any[];
    chartLabels: any[];
    title?: string;
    displayLegend: boolean;
}

const PieChartComponent: FC<IPieChartComponent> = (chartData) => {
    const colorPalette = [
        'rgba(215, 48, 39, 1)',
        'rgba(244, 109, 67, 1)',
        'rgba(253, 174, 97, 1)',
        'rgba(254, 224, 144, 1)',
        'rgba(255, 255, 191, 1)',
        'rgba(224, 243, 248, 1)',
        'rgba(171, 217, 233, 1)',
        'rgba(116, 173, 209, 1)',
        'rgba(69, 117, 180, 1)',
        'rgba(197, 27, 125, 1)',
        'rgba(222, 119, 174, 1)',
        'rgba(241, 182, 218, 1)',
        'rgba(184, 225, 134, 1)',
        'rgba(77, 146, 33, 1)',
        'rgba(140, 81, 10, 1)',
    ];

    const colors = _.sampleSize(colorPalette, chartData.chartData.length);

    const data = {
        labels: chartData.chartLabels,
        datasets: [
            {
                display: false,
                label: '# of Games',
                data: chartData.chartData,
                backgroundColor: colors,
                borderColor: 'grey',
                borderWidth: 1,
            },
        ],
    };
    const options = {
        plugins: {
            legend: { display: chartData.displayLegend },
            title: {
                display: true,
                text: chartData.title,
                color: 'darkgoldenrod',
                font: { size: '20' },
            },
        },
    };
    return (
        <Flex marginY="20px">
            <Pie data={data} options={options} width={400} height={400} />
        </Flex>
    );
};

export default memo(PieChartComponent);
