import React from 'react';
import ReactDOM from 'react-dom';
import { BrowserRouter, Route, Routes, Navigate } from 'react-router-dom';
import { ChakraProvider, extendTheme } from '@chakra-ui/react';
import { Provider } from 'react-redux';

import { Login, PlayerDetails, Players, Statistics } from 'src/pages';
import { InitProvider, ProtectedRoute, UnprotectedRoute } from 'src/components';
import { paths } from 'src/constants';
import { store } from 'src/store';
import { theme } from 'src/style';

ReactDOM.render(
    <Provider store={store}>
        <BrowserRouter>
            <ChakraProvider theme={extendTheme(theme)}>
                <InitProvider>
                    <Routes>
                        <Route
                            path={paths.PLAYERS}
                            element={<ProtectedRoute element={Players} />}
                        />
                        <Route
                            path={paths.PLAYER_DETAILS}
                            element={<ProtectedRoute element={PlayerDetails} />}
                        />
                        <Route
                            path={paths.STATISTICS}
                            element={<ProtectedRoute element={Statistics} />}
                        />
                        <Route path={paths.LOGIN} element={<UnprotectedRoute element={Login} />} />
                        <Route path={`${paths.BASE}*`} element={<Navigate to={paths.PLAYERS} />} />
                        <Route path={`/*`} element={<Navigate to={paths.PLAYERS} />} />
                    </Routes>
                </InitProvider>
            </ChakraProvider>
        </BrowserRouter>
    </Provider>,
    document.getElementById('root'),
);
