import React, { FC, memo, useCallback } from 'react';
import { useNavigate } from 'react-router-dom';
import { useSelector } from 'react-redux';

import { Box, Flex, Image, useToast } from '@chakra-ui/react';

import { LoginForm } from 'src/components';

import { paths } from 'src/constants';
import { actions, dispatch, selectors } from 'src/store';

import emblem from 'src/images/emblem.png';

const Login: FC = () => {
    const action = dispatch();
    const toast = useToast();
    const navigate = useNavigate();
    const isSubmitting = useSelector(selectors.auth.selectIsSubmitting);
    const { login } = actions.auth;

    const handleLogin = useCallback(
        (values) =>
            action(login(values)).then((response) => {
                if ('error' in response) {
                    toast({
                        title: 'Username or password are not correct!',
                        status: 'error',
                        position: 'bottom-left',
                        duration: 2000,
                        isClosable: true,
                    });
                } else {
                    navigate(paths.BASE);
                }
            }),
        [action, login, navigate, toast],
    );

    return (
        <Flex bg="blue.10" height="100%">
            <Box width="45%" alignSelf="center">
                <Image src={emblem} margin="auto" width="80%" height="80%" />
            </Box>
            {isSubmitting && <Box>Loading...</Box>}
            <Flex direction="column" width="55%" margin="auto" padding="6% 14%">
                <LoginForm
                    handleSubmit={handleLogin}
                    initialValues={{ username: '', password: '' }}
                />
            </Flex>
        </Flex>
    );
};

export default memo(Login);
