/* eslint-disable react/display-name */
import React, { FC, memo } from 'react';
import { Flex } from '@chakra-ui/react';
import { useSelector } from 'react-redux';

import { selectors } from 'src/store';
import { BarChartComponent, Loader, PieChartComponent } from 'src/components';

const Statistics: FC = () => {
    const hasLoaded = useSelector(selectors.players.selectHasLoaded);
    const players = useSelector(selectors.players.selectPlayers);

    const filterData = (labelString: 'name', dataString: 'games') => {
        const filteredData = players.map((player) => {
            return { label: player[labelString] || '', data: player[dataString] || 0 };
        });
        return filteredData;
    };

    const countData = (countAttribute: string, countString: string) => {
        const countedData = players.filter(
            (player: any) => player[`${countAttribute}`] === `${countString}`,
        ).length;
        return countedData;
    };

    const gamesData = filterData('name', 'games');
    gamesData.sort((a: { label: string; data: number }, b: { label: string; data: number }) => {
        return b.data - a.data;
    });
    gamesData.splice(10);

    const legData: { data: number[]; label: string[] } = {
        data: [],
        label: [],
    };
    legData.label = ['Right', 'Both', 'Left'];
    legData.data = [
        countData('leg', legData.label[0].charAt(0)),
        countData('leg', legData.label[1].charAt(0)),
        countData('leg', legData.label[2].charAt(0)),
    ];

    if (!hasLoaded) {
        return <Loader />;
    }

    return (
        <Flex justifyContent="space-evenly" flexWrap="wrap">
            <BarChartComponent
                chartData={gamesData.map((player) => {
                    return player.data;
                })}
                chartLabels={gamesData.map((player) => {
                    return player.label;
                })}
                title="# of games"
            />
            <PieChartComponent
                chartData={legData.data}
                chartLabels={legData.label}
                title="# of players based on stronger leg"
                displayLegend={true}
            />
        </Flex>
    );
};

export default memo(Statistics);
