import { createAsyncThunk } from '@reduxjs/toolkit';

import config from 'src/config';
import { paths } from 'src/constants';

import { PlayerData } from 'src/constants/interfaces/player';

const headers = {
    'Content-Type': 'multipart/form-data',
};

const getPlayer = createAsyncThunk('getPlayer', async (id: number) =>
    config.axios.get(paths.build(paths.API.PLAYER_DETAILS, id)),
);

const editPlayer = createAsyncThunk(
    'editPlayer',
    async (data: { formData: PlayerData; id: string }) =>
        config.axios.put(paths.build(paths.API.PLAYER_DETAILS, data.id), data.formData, {
            headers,
        }),
);

const addPlayer = createAsyncThunk('addPlayer', async (data: PlayerData) =>
    config.axios.post(paths.API.PLAYERS, data),
);

const deletePlayer = createAsyncThunk('deletePlayer', async (id: string) =>
    config.axios.delete(paths.build(paths.API.PLAYER_DETAILS, id)),
);

export default { getPlayer, editPlayer, addPlayer, deletePlayer };
