import { createSlice, PayloadAction } from '@reduxjs/toolkit';

// import config from 'src/config';
import { actions } from 'src/store';

import { AuthPayloadData, AuthPayload, AuthState } from 'src/constants/interfaces/auth';

const authActions = actions.auth;

const initialState: AuthState = {
    data: <AuthPayloadData>{},
    isSubmitting: false,
    hasLoaded: false,
};

const extraReducers = {
    [authActions.login.pending.type]: (state: AuthState) => ({
        ...state,
        isSubmitting: true,
    }),
    [authActions.login.fulfilled.type]: (
        state: AuthState,
        { payload }: PayloadAction<AuthPayload>,
    ) => {
        localStorage.setItem('accessToken', payload.data.token);

        return {
            ...state,
            data: payload.data,
            isSubmitting: false,
            hasLoaded: true,
        };
    },
    [authActions.login.rejected.type]: (state: AuthState) => ({
        ...state,
        isSubmitting: false,
    }),

    [authActions.logout.fulfilled.type]: () => ({
        ...initialState,
    }),

    [authActions.health.fulfilled.type]: (
        state: AuthState,
        { payload }: PayloadAction<AuthPayload>,
    ) => ({
        ...state,
        data: { ...state.data, ...payload.data },
    }),
    [authActions.health.rejected.type]: () => localStorage.clear(),
};

const auth = createSlice({
    name: 'auth',
    initialState,
    reducers: {},
    extraReducers,
});

export default auth.reducer;
