import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import {
    GeneralData,
    GeneralPayload,
    GeneralState,
} from 'src/constants/interfaces/generalMedicalOverview';

const generalActions = actions.general;

const initialState: GeneralState = {
    data: <GeneralData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [generalActions.getGeneralOverview.pending.type]: (state: GeneralState) => ({
        ...state,
        hasLoaded: false,
    }),
    [generalActions.getGeneralOverview.fulfilled.type]: (
        state: GeneralState,
        { payload }: PayloadAction<GeneralPayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [generalActions.getGeneralOverview.rejected.type]: (state: GeneralState) => ({
        ...state,
        hasLoaded: true,
    }),

    [generalActions.addGeneralOverview.pending.type]: (state: GeneralState) => ({
        ...state,
        isSubmitting: true,
    }),
    [generalActions.addGeneralOverview.fulfilled.type]: (state: GeneralState) => ({
        ...state,
        isSubmitting: false,
    }),
    [generalActions.addGeneralOverview.rejected.type]: (state: GeneralState) => ({
        ...state,
        isSubmitting: false,
    }),
};

const general = createSlice({
    name: 'general',
    initialState,
    reducers: {},
    extraReducers,
});

export default general.reducer;
