import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import {
    AnamnesisData,
    AnamnesisPayload,
    AnamnesisState,
} from 'src/constants/interfaces/medicalAnamnesis';

const medicalAnamnesisActions = actions.medicalAnamnesis;

const initialState: AnamnesisState = {
    data: <AnamnesisData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [medicalAnamnesisActions.getMedicalAnamnesis.pending.type]: (state: AnamnesisState) => ({
        ...state,
        hasLoaded: false,
    }),
    [medicalAnamnesisActions.getMedicalAnamnesis.fulfilled.type]: (
        state: AnamnesisState,
        { payload }: PayloadAction<AnamnesisPayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [medicalAnamnesisActions.getMedicalAnamnesis.rejected.type]: (state: AnamnesisState) => ({
        ...state,
        hasLoaded: true,
    }),

    [medicalAnamnesisActions.addMedicalAnamnesis.pending.type]: (state: AnamnesisState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicalAnamnesisActions.addMedicalAnamnesis.fulfilled.type]: (state: AnamnesisState) => ({
        ...state,
        isSubmitting: false,
    }),
    [medicalAnamnesisActions.addMedicalAnamnesis.rejected.type]: (state: AnamnesisState) => ({
        ...state,
        isSubmitting: false,
    }),
};

const anamnesis = createSlice({
    name: 'anamnesis',
    initialState,
    reducers: {},
    extraReducers,
});

export default anamnesis.reducer;
