import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import { MedicineData, MedicinePayload, MedicineState } from 'src/constants/interfaces/medicine';

const medicineActions = actions.medicine;

const initialState: MedicineState = {
    data: <MedicineData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [medicineActions.getMedicine.pending.type]: (state: MedicineState) => ({
        ...state,
        hasLoaded: false,
    }),
    [medicineActions.getMedicine.fulfilled.type]: (
        state: MedicineState,
        { payload }: PayloadAction<MedicinePayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [medicineActions.getMedicine.rejected.type]: (state: MedicineState) => ({
        ...state,
        hasLoaded: true,
    }),

    [medicineActions.addMedicine.pending.type]: (state: MedicineState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicineActions.addMedicine.fulfilled.type]: (
        state: MedicineState,
        { payload }: PayloadAction<MedicinePayload>,
    ) => ({
        ...state,
        data: payload.data,
        isSubmitting: false,
    }),
    [medicineActions.addMedicine.rejected.type]: (state: MedicineState) => ({
        ...state,
        isSubmitting: false,
    }),

    [medicineActions.deleteMedicine.pending.type]: (state: MedicineState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicineActions.deleteMedicine.fulfilled.type]: (state: MedicineState) => ({
        ...state,
        isSubmitting: false,
    }),
    [medicineActions.deleteMedicine.rejected.type]: (state: MedicineState) => ({
        ...state,
        isSubmitting: false,
    }),
};

const medicine = createSlice({
    name: 'medicine',
    initialState,
    reducers: {},
    extraReducers,
});

export default medicine.reducer;
