import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import { PlayerData, PlayerPayload, PlayerState } from 'src/constants/interfaces/player';

const playerActions = actions.player;

const initialState: PlayerState = {
    data: <PlayerData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [playerActions.getPlayer.pending.type]: (state: PlayerState) => ({
        ...state,
        hasLoaded: false,
    }),
    [playerActions.getPlayer.fulfilled.type]: (
        state: PlayerState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [playerActions.getPlayer.rejected.type]: (state: PlayerState) => ({
        ...state,
        hasLoaded: true,
    }),

    [playerActions.editPlayer.pending.type]: (state: PlayerState) => ({
        ...state,
        isSubmitting: true,
    }),
    [playerActions.editPlayer.fulfilled.type]: (
        state: PlayerState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: payload.data,
        isSubmitting: false,
    }),
    [playerActions.editPlayer.rejected.type]: (state: PlayerState) => ({
        ...state,
        isSubmitting: false,
    }),

    [playerActions.addPlayer.pending.type]: (state: PlayerState) => ({
        ...state,
        isSubmitting: true,
    }),
    [playerActions.addPlayer.fulfilled.type]: (
        state: PlayerState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: payload.data,
        isSubmitting: false,
    }),
    [playerActions.addPlayer.rejected.type]: (state: PlayerState) => ({
        ...state,
        isSubmitting: false,
    }),
};

const player = createSlice({
    name: 'player',
    initialState,
    reducers: {},
    extraReducers,
});

export default player.reducer;
