import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import { PlayersData, PlayersPayload, PlayersState } from 'src/constants/interfaces/players';
import { PlayerPayload } from 'src/constants/interfaces/player';
import { VaccinationPayload } from 'src/constants/interfaces/vaccination';
import { MedicinePayload } from 'src/constants/interfaces/medicine';
import { AnamnesisPayload } from 'src/constants/interfaces/medicalAnamnesis';
import { GeneralPayload } from 'src/constants/interfaces/generalMedicalOverview';

const generalActions = actions.general;
const medicalAnamnesisActions = actions.medicalAnamnesis;
const medicineActions = actions.medicine;
const playerActions = actions.player;
const playersActions = actions.players;
const vaccinationActions = actions.vaccination;

const initialState: PlayersState = {
    data: <PlayersData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [playersActions.getPlayers.pending.type]: (state: PlayersState) => ({
        ...state,
    }),
    [playersActions.getPlayers.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<PlayersPayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [playersActions.getPlayers.rejected.type]: (state: PlayersState) => ({
        ...state,
        hasLoaded: true,
    }),

    [playerActions.addPlayer.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [playerActions.addPlayer.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: [...state.data, payload.data],
        isSubmitting: false,
        hasLoaded: true,
    }),
    [playerActions.addPlayer.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [playerActions.editPlayer.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [playerActions.editPlayer.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.id) {
                return payload.data;
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [playerActions.editPlayer.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [playerActions.deletePlayer.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [playerActions.deletePlayer.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<PlayerPayload>,
    ) => ({
        ...state,
        data: state.data.filter((player) => player.id !== payload.data.id),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [playerActions.deletePlayer.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [generalActions.addGeneralOverview.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [generalActions.addGeneralOverview.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<GeneralPayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    general_medical_overview: [...player.general_medical_overview, payload.data],
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [generalActions.addGeneralOverview.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [generalActions.deleteGeneralOverview.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [generalActions.deleteGeneralOverview.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<GeneralPayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    general_medical_overview: player.general_medical_overview.filter(
                        (general) => general.id !== payload.data.id,
                    ),
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [generalActions.deleteGeneralOverview.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [medicalAnamnesisActions.addMedicalAnamnesis.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicalAnamnesisActions.addMedicalAnamnesis.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<AnamnesisPayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    medical_anamnesis: [...player.medical_anamnesis, payload.data],
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [medicalAnamnesisActions.addMedicalAnamnesis.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [medicalAnamnesisActions.deleteMedicalAnamnesis.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicalAnamnesisActions.deleteMedicalAnamnesis.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<AnamnesisPayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    medical_anamnesis: player.medical_anamnesis.filter(
                        (medical) => medical.id !== payload.data.id,
                    ),
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [medicalAnamnesisActions.deleteMedicalAnamnesis.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [medicineActions.addMedicine.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicineActions.addMedicine.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<MedicinePayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    medicine: [
                        ...player.medicine,
                        {
                            ...payload.data,
                            TUE: payload.data.TUE
                                ? `${process.env.REACT_APP_API_URL}${payload.data.TUE}`
                                : undefined,
                        },
                    ],
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [medicineActions.addMedicine.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [medicineActions.deleteMedicine.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [medicineActions.deleteMedicine.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<MedicinePayload>,
    ) => ({
        ...state,
        data: state.data.map((player) => {
            if (player.id === payload.data.player) {
                return {
                    ...player,
                    medicine: player.medicine.filter((medicine) => medicine.id !== payload.data.id),
                };
            }
            return player;
        }),
        isSubmitting: false,
        hasLoaded: true,
    }),
    [medicineActions.deleteMedicine.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [vaccinationActions.addVaccine.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [vaccinationActions.addVaccine.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<VaccinationPayload>,
    ) => {
        return {
            ...state,
            data: state.data.map((player) => {
                if (player.id === payload.data.player) {
                    return { ...player, vaccination: [...player.vaccination, payload.data] };
                }
                return player;
            }),
            isSubmitting: false,
            hasLoaded: true,
        };
    },
    [vaccinationActions.addVaccine.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),

    [vaccinationActions.deleteVaccine.pending.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: true,
    }),
    [vaccinationActions.deleteVaccine.fulfilled.type]: (
        state: PlayersState,
        { payload }: PayloadAction<VaccinationPayload>,
    ) => {
        console.log(payload.data);
        return {
            ...state,
            data: state.data.map((player) => {
                if (player.id === payload.data.player) {
                    return {
                        ...player,
                        vaccination: player.vaccination.filter(
                            (vaccination) => vaccination.id !== payload.data.id,
                        ),
                    };
                }
                return player;
            }),
            isSubmitting: false,
            hasLoaded: true,
        };
    },
    [vaccinationActions.deleteVaccine.rejected.type]: (state: PlayersState) => ({
        ...state,
        isSubmitting: false,
        hasLoaded: true,
    }),
};

const players = createSlice({
    name: 'players',
    initialState,
    reducers: {},
    extraReducers,
});

export default players.reducer;
