import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { actions } from 'src/store';

import {
    VaccinationData,
    VaccinationPayload,
    VaccinationState,
} from 'src/constants/interfaces/vaccination';

const vaccinationActions = actions.vaccination;

const initialState: VaccinationState = {
    data: <VaccinationData>{},
    hasLoaded: false,
    isSubmitting: false,
};

const extraReducers = {
    [vaccinationActions.getVaccines.pending.type]: (state: VaccinationState) => ({
        ...state,
        hasLoaded: false,
    }),
    [vaccinationActions.getVaccines.fulfilled.type]: (
        state: VaccinationState,
        { payload }: PayloadAction<VaccinationPayload>,
    ) => ({
        ...state,
        data: payload.data,
        hasLoaded: true,
    }),
    [vaccinationActions.getVaccines.rejected.type]: (state: VaccinationState) => ({
        ...state,
        hasLoaded: true,
    }),

    [vaccinationActions.addVaccine.pending.type]: (state: VaccinationState) => ({
        ...state,
        isSubmitting: true,
    }),
    [vaccinationActions.addVaccine.fulfilled.type]: (
        state: VaccinationState,
        { payload }: PayloadAction<VaccinationPayload>,
    ) => ({
        ...state,
        data: payload.data,
        isSubmitting: false,
    }),
    [vaccinationActions.addVaccine.rejected.type]: (state: VaccinationState) => ({
        ...state,
        isSubmitting: false,
    }),

    [vaccinationActions.deleteVaccine.pending.type]: (state: VaccinationState) => ({
        ...state,
        isSubmitting: true,
    }),
    [vaccinationActions.deleteVaccine.fulfilled.type]: (state: VaccinationState) => ({
        ...state,
        isSubmitting: false,
    }),
    [vaccinationActions.deleteVaccine.rejected.type]: (state: VaccinationState) => ({
        ...state,
        isSubmitting: false,
    }),
};

const medicine = createSlice({
    name: 'medicine',
    initialState,
    reducers: {},
    extraReducers,
});

export default medicine.reducer;
