from django.contrib.auth.models import User
from django.core.management.base import BaseCommand
from django.conf import settings
from medical_api.medical.models import Player
from medical_api.medical.management.commands.data.populate_db import PLAYERS_DATA
import datetime


def log(message):
    print(
        "(%s): %s" %
        (datetime.datetime.now().strftime("%d.%m.%Y. %H:%M"), message)
    )


class Command(BaseCommand):
    help = 'Deletes every object from the database and sets initial values'

    def add_players(self, *args, **options):

        for player in PLAYERS_DATA:
            p = Player()
            p.name = player['name']
            p.position = player['position']
            p.leg = player['leg']
            p.date_of_birth = player['date_of_birth']
            p.games = player['games']
            p.save()

    def handle(self, *args, **options):

        if settings.DEBUG:
            # these objects should not be created or deleted in production
            if not User.objects.exists():
                # create superuser
                User.objects.create_superuser(
                    username='admin',
                    email='admin@example.com',
                    password='admin',
                    is_active=True
                )
                log("Superuser created.")

            if Player.objects.exists():
                # delete objects
                Player.objects.all().delete()
                log("Players have been destroyed.")

                log("Test database cleared.")

            # create objects
            self.add_players()
            log("Players have been added.")

            log("Test database populated.")
        else:
            log(
                "Database cannot be destroyed and repopulated in production!\
                 Use empty migrations instead!"
            )
