from django.db import models
from django.utils.translation import gettext_lazy as _
from multiselectfield import MultiSelectField

from medical_api.medical.models import Player

from medical_api.medical.models.constants.choices import MedicalAnamnesisChoices


class MedicalAnamnesis(models.Model):
    FAMILY_CHOICES = MedicalAnamnesisChoices.FAMILY_CHOICES
    PLAYER_CHOICES = MedicalAnamnesisChoices.PLAYER_CHOICES
    SYMPTOMS_CHOICES = MedicalAnamnesisChoices.SYMPTOMS_CHOICES

    time_made = models.DateTimeField(
        auto_now_add=True, verbose_name=_('Time made'))
    family_anamnesis = MultiSelectField(
        choices=FAMILY_CHOICES, blank=True, verbose_name=_('Family anamnesis'))
    player_anamnesis = MultiSelectField(
        choices=PLAYER_CHOICES, blank=True, verbose_name=_('Player anamnesis'))
    symptoms = MultiSelectField(
        choices=SYMPTOMS_CHOICES, blank=True, verbose_name=_('Symptoms'))

    player = models.ForeignKey(
        Player, related_name='medical_anamnesis', on_delete=models.SET_NULL, null=True)

    def get_fields(self):
        return [field for field in MedicalAnamnesis._meta.fields]

    class Meta:
        verbose_name = _('Medical Anamnesis')
        verbose_name_plural = _('Medical Anamneses')
