from django.db import models
from django.utils.translation import gettext_lazy as _
from django.conf import settings


class Player(models.Model):
    LEG_CHOICES = (
        ('R', _('Right')),
        ('L', _('Left')),
        ('B', _('Both')),
    )

    name = models.CharField(max_length=100, verbose_name=_('Name'))
    position = models.CharField(max_length=100, verbose_name=_('Position'))
    leg = models.CharField(
        max_length=1, verbose_name=_('Leg'), choices=LEG_CHOICES)
    date_of_birth = models.DateField(
        blank=True, verbose_name=_('Date of birth'))
    games = models.PositiveIntegerField(
        blank=True, verbose_name=_('Number of games'))
    image = models.FileField(upload_to=settings.UPLOAD_FOLDER,
                             blank=True, verbose_name=_('Image'))

    def __str__(self):
        return f"{self.name}"

    def get_fields(self):
        return [field for field in Player._meta.fields]

    class Meta:
        verbose_name_plural = _('Players')
